@@ -382,7 +382,7 @@ float PrayTime::calcJD(int year, int month, int day) {
         void PrayTime::adjustTimes(float * array) {
                 float *times = array;
                 for (int i = 0; i < 7; i++)
-                        times[i] += timeZone - lng / 15;
+                        times[i] += timeZone - lng / 15.0;
                 times[2] += 1 / 60; //Dhuhr
                 if (calculationMethod.getMaghribSelector() == 1) // Maghrib
                         times[5] = times[4] + calculationMethod.getMaghribParam() / 60;
@@ -478,7 +478,7 @@ float PrayTime::calcJD(int year, int month, int day) {
 
         // return prayer times for a given date
         void PrayTime::getDatePrayerTimes(int year, int month, int day, float latitude,
-                        float longitude, int tZ) {
+                        float longitude, float tZ) {
                 float jd;
                 jd = calcJD(year, month, day);
                 //Date currentDate;
@@ -491,7 +491,7 @@ float PrayTime::calcJD(int year, int month, int day) {
         }
 
         // return prayer times for a given date
-        void PrayTime::getPrayerTimes(QDateTime dateTime, float latitude, float longitude, int timeZone) {
+        void PrayTime::getPrayerTimes(QDateTime dateTime, float latitude, float longitude, float timeZone) {
             getDatePrayerTimes(dateTime.date().year(), dateTime.date().month(), dateTime.date().day(), latitude, longitude, timeZone);
         }
 
