@@ -11,7 +11,7 @@ public:
     PrayerTimeSettings();
     double getLatitude();
     double getLongitude();
-    int getTimeZone();
+    double getTimeZone();
     int getCalcMethod();
     int getJuristicMethod();
     int getLatMethod();
@@ -22,7 +22,7 @@ public:
 private:
     double lat;
     double longitude;
-    int timeZone;
+    double timeZone;
     int calcMethod;
     int juristicMethod;
     int latMethod;
